summaryrefslogtreecommitdiff
path: root/vcl
diff options
context:
space:
mode:
Diffstat (limited to 'vcl')
-rw-r--r--vcl/backendtest/outputdevice/outputdevice.cxx6
-rw-r--r--vcl/source/filter/wmf/emfwr.cxx10
-rw-r--r--vcl/source/filter/wmf/winmtf.cxx16
-rw-r--r--vcl/source/filter/wmf/wmfwr.cxx18
-rw-r--r--vcl/source/gdi/metaact.cxx4
-rw-r--r--vcl/source/gdi/print.cxx2
-rw-r--r--vcl/source/gdi/svmconverter.cxx22
-rw-r--r--vcl/source/gdi/virdev.cxx2
-rw-r--r--vcl/source/outdev/bitmap.cxx6
-rw-r--r--vcl/source/outdev/gradient.cxx6
-rw-r--r--vcl/source/outdev/line.cxx4
-rw-r--r--vcl/source/outdev/mask.cxx2
-rw-r--r--vcl/source/outdev/outdev.cxx8
-rw-r--r--vcl/source/outdev/outdevstate.cxx16
-rw-r--r--vcl/source/outdev/polygon.cxx6
-rw-r--r--vcl/source/outdev/polyline.cxx4
-rw-r--r--vcl/source/outdev/transparent.cxx2
-rw-r--r--vcl/source/outdev/wallpaper.cxx6
-rw-r--r--vcl/source/window/paint.cxx6
-rw-r--r--vcl/source/window/window.cxx4
-rw-r--r--vcl/workben/outdevgrind.cxx12
-rw-r--r--vcl/workben/vcldemo.cxx10
22 files changed, 86 insertions, 86 deletions
diff --git a/vcl/backendtest/outputdevice/outputdevice.cxx b/vcl/backendtest/outputdevice/outputdevice.cxx
index 6bc4278b8f65..6f7ed16df824 100644
--- a/vcl/backendtest/outputdevice/outputdevice.cxx
+++ b/vcl/backendtest/outputdevice/outputdevice.cxx
@@ -38,15 +38,15 @@ Bitmap OutputDeviceTestAnotherOutDev::setupXOR()
Rectangle aScissorRectangle(maVDRectangle);
aScissorRectangle.shrink(4);
- mpVirtualDevice->SetRasterOp(ROP_XOR);
+ mpVirtualDevice->SetRasterOp(RasterOp::Xor);
mpVirtualDevice->SetFillColor(constFillColor);
mpVirtualDevice->DrawRect(aDrawRectangle);
- mpVirtualDevice->SetRasterOp(ROP_0);
+ mpVirtualDevice->SetRasterOp(RasterOp::N0);
mpVirtualDevice->SetFillColor(COL_BLACK);
mpVirtualDevice->DrawRect(aScissorRectangle);
- mpVirtualDevice->SetRasterOp(ROP_XOR);
+ mpVirtualDevice->SetRasterOp(RasterOp::Xor);
mpVirtualDevice->SetFillColor(constFillColor);
mpVirtualDevice->DrawRect(aDrawRectangle);
diff --git a/vcl/source/filter/wmf/emfwr.cxx b/vcl/source/filter/wmf/emfwr.cxx
index eeacabe06f65..5d65c6c10f4f 100644
--- a/vcl/source/filter/wmf/emfwr.cxx
+++ b/vcl/source/filter/wmf/emfwr.cxx
@@ -333,7 +333,7 @@ bool EMFWriter::WriteEMF(const GDIMetaFile& rMtf)
m_rStm.WriteInt32( 0 ).WriteInt32( 0 );
ImplEndRecord();
- ImplWriteRasterOp( ROP_OVERPAINT );
+ ImplWriteRasterOp( RasterOp::OverPaint );
ImplBeginRecord( WIN_EMR_SETBKMODE );
m_rStm.WriteUInt32( 1 ); // TRANSPARENT
@@ -625,9 +625,9 @@ void EMFWriter::ImplWriteRasterOp( RasterOp eRop )
switch( eRop )
{
- case ROP_INVERT: nROP2 = 6; break;
- case ROP_XOR: nROP2 = 7; break;
- default: nROP2 = 13;break;
+ case RasterOp::Invert: nROP2 = 6; break;
+ case RasterOp::Xor: nROP2 = 7; break;
+ default: nROP2 = 13;break;
}
ImplBeginRecord( WIN_EMR_SETROP2 );
@@ -839,7 +839,7 @@ void EMFWriter::ImplWriteBmpRecord( const Bitmap& rBmp, const Point& rPt,
const sal_uLong nOffPos = m_rStm.Tell();
m_rStm.SeekRel( 16 );
- m_rStm.WriteUInt32( 0 ).WriteInt32( ( ROP_XOR == maVDev->GetRasterOp() && WIN_SRCCOPY == nROP ) ? WIN_SRCINVERT : nROP );
+ m_rStm.WriteUInt32( 0 ).WriteInt32( ( RasterOp::Xor == maVDev->GetRasterOp() && WIN_SRCCOPY == nROP ) ? WIN_SRCINVERT : nROP );
ImplWriteSize( rSz );
WriteDIB(rBmp, aMemStm, true, false);
diff --git a/vcl/source/filter/wmf/winmtf.cxx b/vcl/source/filter/wmf/winmtf.cxx
index 62bf50f874ca..de2a01294102 100644
--- a/vcl/source/filter/wmf/winmtf.cxx
+++ b/vcl/source/filter/wmf/winmtf.cxx
@@ -827,8 +827,8 @@ WinMtfOutput::WinMtfOutput( GDIMetaFile& rGDIMetaFile ) :
mnTextLayoutMode ( ComplexTextLayoutFlags::Default ),
mnLatestBkMode ( BkMode::NONE ),
mnBkMode ( BkMode::OPAQUE ),
- meLatestRasterOp ( ROP_INVERT ),
- meRasterOp ( ROP_OVERPAINT ),
+ meLatestRasterOp ( RasterOp::Invert ),
+ meRasterOp ( RasterOp::OverPaint ),
maActPos ( Point() ),
mbNopMode ( false ),
mbFillStyleSelected ( false ),
@@ -865,8 +865,8 @@ WinMtfOutput::WinMtfOutput( GDIMetaFile& rGDIMetaFile ) :
maLatestFillStyle.aFillColor = Color( 0x12, 0x34, 0x56 );
mnRop = WMFRasterOp::Black;
- meRasterOp = ROP_OVERPAINT;
- mpGDIMetaFile->AddAction( new MetaRasterOpAction( ROP_OVERPAINT ) );
+ meRasterOp = RasterOp::OverPaint;
+ mpGDIMetaFile->AddAction( new MetaRasterOpAction( RasterOp::OverPaint ) );
}
WinMtfOutput::~WinMtfOutput()
@@ -952,16 +952,16 @@ WMFRasterOp WinMtfOutput::SetRasterOp( WMFRasterOp nRasterOp )
switch( nRasterOp )
{
case WMFRasterOp::Not:
- meRasterOp = ROP_INVERT;
+ meRasterOp = RasterOp::Invert;
break;
case WMFRasterOp::XorPen:
- meRasterOp = ROP_XOR;
+ meRasterOp = RasterOp::Xor;
break;
case WMFRasterOp::Nop:
{
- meRasterOp = ROP_OVERPAINT;
+ meRasterOp = RasterOp::OverPaint;
if( !mbNopMode )
{
m_NopFillStyle = maFillStyle;
@@ -974,7 +974,7 @@ WMFRasterOp WinMtfOutput::SetRasterOp( WMFRasterOp nRasterOp )
break;
default:
- meRasterOp = ROP_OVERPAINT;
+ meRasterOp = RasterOp::OverPaint;
break;
}
}
diff --git a/vcl/source/filter/wmf/wmfwr.cxx b/vcl/source/filter/wmf/wmfwr.cxx
index 68e7c9f1ca74..9bf1431e83b1 100644
--- a/vcl/source/filter/wmf/wmfwr.cxx
+++ b/vcl/source/filter/wmf/wmfwr.cxx
@@ -142,12 +142,12 @@ WMFWriter::WMFWriter()
, nMetafileHeaderPos(0)
, nMaxRecordSize(0)
, nActRecordPos(0)
- , eSrcRasterOp(ROP_OVERPAINT)
+ , eSrcRasterOp(RasterOp::OverPaint)
, eSrcTextAlign(ALIGN_BASELINE)
, bSrcIsClipping(false)
, pAttrStack(nullptr)
, eSrcHorTextAlign(W_TA_LEFT)
- , eDstROP2(ROP_OVERPAINT)
+ , eDstROP2(RasterOp::OverPaint)
, eDstTextAlign(ALIGN_BASELINE)
, eDstHorTextAlign(W_TA_LEFT)
, bDstIsClipping(false)
@@ -723,9 +723,9 @@ void WMFWriter::WMFRecord_SetROP2(RasterOp eROP)
sal_uInt16 nROP2;
switch (eROP) {
- case ROP_INVERT: nROP2=W_R2_NOT; break;
- case ROP_XOR: nROP2=W_R2_XORPEN; break;
- default: nROP2=W_R2_COPYPEN;
+ case RasterOp::Invert: nROP2=W_R2_NOT; break;
+ case RasterOp::Xor: nROP2=W_R2_XORPEN; break;
+ default: nROP2=W_R2_COPYPEN;
}
WriteRecordHeader(0x00000004,W_META_SETROP2);
pWMF->WriteUInt16( nROP2 );
@@ -797,9 +797,9 @@ void WMFWriter::WMFRecord_StretchDIB( const Point & rPoint, const Size & rSize,
{
switch( eSrcRasterOp )
{
- case ROP_INVERT: nROP = W_DSTINVERT; break;
- case ROP_XOR: nROP = W_SRCINVERT; break;
- default: nROP = W_SRCCOPY;
+ case RasterOp::Invert: nROP = W_DSTINVERT; break;
+ case RasterOp::Xor: nROP = W_SRCINVERT; break;
+ default: nROP = W_SRCCOPY;
}
}
@@ -1757,7 +1757,7 @@ bool WMFWriter::WriteWMF( const GDIMetaFile& rMTF, SvStream& rTargetStream,
WMFRecord_SetWindowExt(rMTF.GetPrefSize());
WMFRecord_SetBkMode( true );
- eDstROP2 = eSrcRasterOp = ROP_OVERPAINT;
+ eDstROP2 = eSrcRasterOp = RasterOp::OverPaint;
WMFRecord_SetROP2(eDstROP2);
aDstLineInfo = LineInfo();
diff --git a/vcl/source/gdi/metaact.cxx b/vcl/source/gdi/metaact.cxx
index 059b62e91788..047a207381d8 100644
--- a/vcl/source/gdi/metaact.cxx
+++ b/vcl/source/gdi/metaact.cxx
@@ -2894,7 +2894,7 @@ void MetaPopAction::Read( SvStream& rIStm, ImplMetaReadData* )
MetaRasterOpAction::MetaRasterOpAction() :
MetaAction ( MetaActionType::RASTEROP ),
- meRasterOp ( ROP_OVERPAINT )
+ meRasterOp ( RasterOp::OverPaint )
{}
MetaRasterOpAction::~MetaRasterOpAction()
@@ -2922,7 +2922,7 @@ void MetaRasterOpAction::Write( SvStream& rOStm, ImplMetaWriteData* pData )
{
MetaAction::Write(rOStm, pData);
VersionCompat aCompat(rOStm, StreamMode::WRITE, 1);
- rOStm.WriteUInt16( meRasterOp );
+ rOStm.WriteUInt16( (sal_uInt16)meRasterOp );
}
void MetaRasterOpAction::Read( SvStream& rIStm, ImplMetaReadData* )
diff --git a/vcl/source/gdi/print.cxx b/vcl/source/gdi/print.cxx
index 43bc44b3e244..d2c0f87c3834 100644
--- a/vcl/source/gdi/print.cxx
+++ b/vcl/source/gdi/print.cxx
@@ -586,7 +586,7 @@ bool Printer::AcquireGraphics() const
if ( mpGraphics )
{
- mpGraphics->SetXORMode( (ROP_INVERT == meRasterOp) || (ROP_XOR == meRasterOp) );
+ mpGraphics->SetXORMode( (RasterOp::Invert == meRasterOp) || (RasterOp::Xor == meRasterOp) );
mpGraphics->setAntiAliasB2DDraw(bool(mnAntialiasing & AntialiasingFlags::EnableB2dDraw));
}
diff --git a/vcl/source/gdi/virdev.cxx b/vcl/source/gdi/virdev.cxx
index af95978c0a6a..dfc2f1ef2427 100644
--- a/vcl/source/gdi/virdev.cxx
+++ b/vcl/source/gdi/virdev.cxx
@@ -77,7 +77,7 @@ bool VirtualDevice::AcquireGraphics() const
if ( mpGraphics )
{
- mpGraphics->SetXORMode( (ROP_INVERT == meRasterOp) || (ROP_XOR == meRasterOp) );
+ mpGraphics->SetXORMode( (RasterOp::Invert == meRasterOp) || (RasterOp::Xor == meRasterOp) );
mpGraphics->setAntiAliasB2DDraw(bool(mnAntialiasing & AntialiasingFlags::EnableB2dDraw));
}
diff --git a/vcl/source/outdev/bitmap.cxx b/vcl/source/outdev/bitmap.cxx
index 31b25a2d199a..387bf0d97f98 100644
--- a/vcl/source/outdev/bitmap.cxx
+++ b/vcl/source/outdev/bitmap.cxx
@@ -69,7 +69,7 @@ void OutputDevice::DrawBitmap( const Point& rDestPt, const Size& rDestSize,
{
return;
}
- if ( ROP_INVERT == meRasterOp )
+ if ( RasterOp::Invert == meRasterOp )
{
DrawRect( Rectangle( rDestPt, rDestSize ) );
return;
@@ -295,7 +295,7 @@ void OutputDevice::DrawBitmapEx( const Point& rDestPt, const Size& rDestSize,
if ( mnDrawMode & DrawModeFlags::NoBitmap )
return;
- if ( ROP_INVERT == meRasterOp )
+ if ( RasterOp::Invert == meRasterOp )
{
DrawRect( Rectangle( rDestPt, rDestSize ) );
return;
@@ -1216,7 +1216,7 @@ void OutputDevice::DrawTransformedBitmapEx(
// we have rotation,shear or mirror, check if some crazy mode needs the
// created transformed bitmap
- const bool bInvert(ROP_INVERT == meRasterOp);
+ const bool bInvert(RasterOp::Invert == meRasterOp);
const bool bBitmapChangedColor(mnDrawMode & (DrawModeFlags::BlackBitmap | DrawModeFlags::WhiteBitmap | DrawModeFlags::GrayBitmap | DrawModeFlags::GhostedBitmap));
const bool bMetafile(mpMetaFile);
bool bDone(false);
diff --git a/vcl/source/outdev/gradient.cxx b/vcl/source/outdev/gradient.cxx
index fdf6d33ba53c..696cc6ac90ac 100644
--- a/vcl/source/outdev/gradient.cxx
+++ b/vcl/source/outdev/gradient.cxx
@@ -160,12 +160,12 @@ void OutputDevice::ClipAndDrawGradientMetafile ( const Gradient &rGradient, cons
EnableOutput( false );
Push( PushFlags::RASTEROP );
- SetRasterOp( ROP_XOR );
+ SetRasterOp( RasterOp::Xor );
DrawGradient( aBoundRect, rGradient );
SetFillColor( COL_BLACK );
- SetRasterOp( ROP_0 );
+ SetRasterOp( RasterOp::N0 );
DrawPolyPolygon( rPolyPoly );
- SetRasterOp( ROP_XOR );
+ SetRasterOp( RasterOp::Xor );
DrawGradient( aBoundRect, rGradient );
Pop();
EnableOutput( bOldOutput );
diff --git a/vcl/source/outdev/line.cxx b/vcl/source/outdev/line.cxx
index c12e1e6e98f3..990efb555e34 100644
--- a/vcl/source/outdev/line.cxx
+++ b/vcl/source/outdev/line.cxx
@@ -116,7 +116,7 @@ void OutputDevice::DrawLine( const Point& rStartPt, const Point& rEndPt )
// #i101598# support AA and snap for lines, too
if((mnAntialiasing & AntialiasingFlags::EnableB2dDraw)
&& mpGraphics->supportsOperation(OutDevSupportType::B2DDraw)
- && ROP_OVERPAINT == GetRasterOp()
+ && RasterOp::OverPaint == GetRasterOp()
&& IsLineColor())
{
// at least transform with double precision to device coordinates; this will
@@ -160,7 +160,7 @@ void OutputDevice::drawLine( basegfx::B2DPolyPolygon aLinePolyPolygon, const Lin
{
const bool bTryAA((mnAntialiasing & AntialiasingFlags::EnableB2dDraw)
&& mpGraphics->supportsOperation(OutDevSupportType::B2DDraw)
- && ROP_OVERPAINT == GetRasterOp()
+ && RasterOp::OverPaint == GetRasterOp()
&& IsLineColor());
basegfx::B2DPolyPolygon aFillPolyPolygon;
const bool bDashUsed(LINE_DASH == rInfo.GetStyle());
diff --git a/vcl/source/outdev/mask.cxx b/vcl/source/outdev/mask.cxx
index eaa9ac060fa5..73af2869fff0 100644
--- a/vcl/source/outdev/mask.cxx
+++ b/vcl/source/outdev/mask.cxx
@@ -54,7 +54,7 @@ void OutputDevice::DrawMask( const Point& rDestPt, const Size& rDestSize,
if( ImplIsRecordLayout() )
return;
- if( ROP_INVERT == meRasterOp )
+ if( RasterOp::Invert == meRasterOp )
{
DrawRect( Rectangle( rDestPt, rDestSize ) );
return;
diff --git a/vcl/source/outdev/outdev.cxx b/vcl/source/outdev/outdev.cxx
index 2ea9988406c3..8555f5cd12d4 100644
--- a/vcl/source/outdev/outdev.cxx
+++ b/vcl/source/outdev/outdev.cxx
@@ -94,7 +94,7 @@ OutputDevice::OutputDevice() :
maTextColor = Color( COL_BLACK );
maOverlineColor = Color( COL_TRANSPARENT );
meTextAlign = maFont.GetAlignment();
- meRasterOp = ROP_OVERPAINT;
+ meRasterOp = RasterOp::OverPaint;
mnAntialiasing = AntialiasingFlags::NONE;
meTextLanguage = 0; // TODO: get default from configuration?
mbLineColor = true;
@@ -418,7 +418,7 @@ void OutputDevice::DrawOutDev( const Point& rDestPt, const Size& rDestSize,
if( ImplIsRecordLayout() )
return;
- if ( ROP_INVERT == meRasterOp )
+ if ( RasterOp::Invert == meRasterOp )
{
DrawRect( Rectangle( rDestPt, rDestSize ) );
return;
@@ -475,7 +475,7 @@ void OutputDevice::DrawOutDev( const Point& rDestPt, const Size& rDestSize,
if ( ImplIsRecordLayout() )
return;
- if ( ROP_INVERT == meRasterOp )
+ if ( RasterOp::Invert == meRasterOp )
{
DrawRect( Rectangle( rDestPt, rDestSize ) );
return;
@@ -547,7 +547,7 @@ void OutputDevice::CopyArea( const Point& rDestPt,
return;
RasterOp eOldRop = GetRasterOp();
- SetRasterOp( ROP_OVERPAINT );
+ SetRasterOp( RasterOp::OverPaint );
if ( !IsDeviceOutputNecessary() )
return;
diff --git a/vcl/source/outdev/outdevstate.cxx b/vcl/source/outdev/outdevstate.cxx
index 698c3a4c9581..cf2ef0d59159 100644
--- a/vcl/source/outdev/outdevstate.cxx
+++ b/vcl/source/outdev/outdevstate.cxx
@@ -39,7 +39,7 @@ OutDevState::OutDevState()
, mpOverlineColor(nullptr)
, mpRefPoint(nullptr)
, meTextAlign(ALIGN_TOP)
- , meRasterOp(ROP_OVERPAINT)
+ , meRasterOp(RasterOp::OverPaint)
, mnTextLayoutMode(ComplexTextLayoutFlags::Default)
, meTextLanguage(0)
, mnFlags(PushFlags::NONE)
@@ -297,7 +297,7 @@ void OutputDevice::SetRasterOp( RasterOp eRasterOp )
mbInitLineColor = mbInitFillColor = true;
if( mpGraphics || AcquireGraphics() )
- mpGraphics->SetXORMode( (ROP_INVERT == meRasterOp) || (ROP_XOR == meRasterOp) );
+ mpGraphics->SetXORMode( (RasterOp::Invert == meRasterOp) || (RasterOp::Xor == meRasterOp) );
}
if( mpAlphaVDev )
@@ -576,11 +576,11 @@ void OutputDevice::InitLineColor()
if( mbLineColor )
{
- if( ROP_0 == meRasterOp )
+ if( RasterOp::N0 == meRasterOp )
mpGraphics->SetROPLineColor( SalROPColor::N0 );
- else if( ROP_1 == meRasterOp )
+ else if( RasterOp::N1 == meRasterOp )
mpGraphics->SetROPLineColor( SalROPColor::N1 );
- else if( ROP_INVERT == meRasterOp )
+ else if( RasterOp::Invert == meRasterOp )
mpGraphics->SetROPLineColor( SalROPColor::Invert );
else
mpGraphics->SetLineColor( ImplColorToSal( maLineColor ) );
@@ -598,11 +598,11 @@ void OutputDevice::InitFillColor()
if( mbFillColor )
{
- if( ROP_0 == meRasterOp )
+ if( RasterOp::N0 == meRasterOp )
mpGraphics->SetROPFillColor( SalROPColor::N0 );
- else if( ROP_1 == meRasterOp )
+ else if( RasterOp::N1 == meRasterOp )
mpGraphics->SetROPFillColor( SalROPColor::N1 );
- else if( ROP_INVERT == meRasterOp )
+ else if( RasterOp::Invert == meRasterOp )
mpGraphics->SetROPFillColor( SalROPColor::Invert );
else
mpGraphics->SetFillColor( ImplColorToSal( maFillColor ) );
diff --git a/vcl/source/outdev/polygon.cxx b/vcl/source/outdev/polygon.cxx
index 8c7a58339b60..76d9ec6e6963 100644
--- a/vcl/source/outdev/polygon.cxx
+++ b/vcl/source/outdev/polygon.cxx
@@ -65,7 +65,7 @@ void OutputDevice::DrawPolyPolygon( const tools::PolyPolygon& rPolyPoly )
// use b2dpolygon drawing if possible
if((mnAntialiasing & AntialiasingFlags::EnableB2dDraw) &&
mpGraphics->supportsOperation(OutDevSupportType::B2DDraw) &&
- ROP_OVERPAINT == GetRasterOp() &&
+ RasterOp::OverPaint == GetRasterOp() &&
(IsLineColor() || IsFillColor()))
{
const basegfx::B2DHomMatrix aTransform = ImplGetDeviceTransformation();
@@ -178,7 +178,7 @@ void OutputDevice::DrawPolygon( const tools::Polygon& rPoly )
// use b2dpolygon drawing if possible
if((mnAntialiasing & AntialiasingFlags::EnableB2dDraw) &&
mpGraphics->supportsOperation(OutDevSupportType::B2DDraw) &&
- ROP_OVERPAINT == GetRasterOp() &&
+ RasterOp::OverPaint == GetRasterOp() &&
(IsLineColor() || IsFillColor()))
{
const basegfx::B2DHomMatrix aTransform = ImplGetDeviceTransformation();
@@ -281,7 +281,7 @@ void OutputDevice::ImplDrawPolyPolygonWithB2DPolyPolygon(const basegfx::B2DPolyP
if((mnAntialiasing & AntialiasingFlags::EnableB2dDraw) &&
mpGraphics->supportsOperation(OutDevSupportType::B2DDraw) &&
- ROP_OVERPAINT == GetRasterOp() &&
+ RasterOp::OverPaint == GetRasterOp() &&
(IsLineColor() || IsFillColor()))
{
const basegfx::B2DHomMatrix aTransform(ImplGetDeviceTransformation());
diff --git a/vcl/source/outdev/polyline.cxx b/vcl/source/outdev/polyline.cxx
index 77971000dbfc..289d7926acff 100644
--- a/vcl/source/outdev/polyline.cxx
+++ b/vcl/source/outdev/polyline.cxx
@@ -214,7 +214,7 @@ void OutputDevice::DrawPolyLine( const basegfx::B2DPolygon& rB2DPolygon,
const bool bTryAA((mnAntialiasing & AntialiasingFlags::EnableB2dDraw) &&
mpGraphics->supportsOperation(OutDevSupportType::B2DDraw) &&
- ROP_OVERPAINT == GetRasterOp() &&
+ RasterOp::OverPaint == GetRasterOp() &&
IsLineColor());
// when AA it is necessary to also paint the filled polygon's outline
@@ -314,7 +314,7 @@ bool OutputDevice::DrawPolyLineDirect( const basegfx::B2DPolygon& rB2DPolygon,
const bool bTryAA( bBypassAACheck ||
((mnAntialiasing & AntialiasingFlags::EnableB2dDraw) &&
mpGraphics->supportsOperation(OutDevSupportType::B2DDraw) &&
- ROP_OVERPAINT == GetRasterOp() &&
+ RasterOp::OverPaint == GetRasterOp() &&
IsLineColor()));
if(bTryAA)
diff --git a/vcl/source/outdev/transparent.cxx b/vcl/source/outdev/transparent.cxx
index c8cfebd522c7..ace38d6f944d 100644
--- a/vcl/source/outdev/transparent.cxx
+++ b/vcl/source/outdev/transparent.cxx
@@ -234,7 +234,7 @@ void OutputDevice::DrawTransparent( const basegfx::B2DPolyPolygon& rB2DPolyPoly,
if((mnAntialiasing & AntialiasingFlags::EnableB2dDraw) &&
mpGraphics->supportsOperation(OutDevSupportType::B2DDraw) &&
- (ROP_OVERPAINT == GetRasterOp()) )
+ (RasterOp::OverPaint == GetRasterOp()) )
{
// b2dpolygon support not implemented yet on non-UNX platforms
const basegfx::B2DHomMatrix aTransform = ImplGetDeviceTransformation();
diff --git a/vcl/source/outdev/wallpaper.cxx b/vcl/source/outdev/wallpaper.cxx
index 057089bbc20c..e4d89716f28d 100644
--- a/vcl/source/outdev/wallpaper.cxx
+++ b/vcl/source/outdev/wallpaper.cxx
@@ -94,10 +94,10 @@ void OutputDevice::Erase()
if ( mbBackground )
{
RasterOp eRasterOp = GetRasterOp();
- if ( eRasterOp != ROP_OVERPAINT )
- SetRasterOp( ROP_OVERPAINT );
+ if ( eRasterOp != RasterOp::OverPaint )
+ SetRasterOp( RasterOp::OverPaint );
DrawWallpaper( 0, 0, mnOutWidth, mnOutHeight, maBackground );
- if ( eRasterOp != ROP_OVERPAINT )
+ if ( eRasterOp != RasterOp::OverPaint )
SetRasterOp( eRasterOp );
}
diff --git a/vcl/source/window/paint.cxx b/vcl/source/window/paint.cxx
index f85582acd7b2..d441f076172c 100644
--- a/vcl/source/window/paint.cxx
+++ b/vcl/source/window/paint.cxx
@@ -1516,10 +1516,10 @@ void Window::Erase(vcl::RenderContext& rRenderContext)
if (mbBackground && !bNativeOK)
{
RasterOp eRasterOp = GetRasterOp();
- if (eRasterOp != ROP_OVERPAINT)
- SetRasterOp(ROP_OVERPAINT);
+ if (eRasterOp != RasterOp::OverPaint)
+ SetRasterOp(RasterOp::OverPaint);
rRenderContext.DrawWallpaper(0, 0, mnOutWidth, mnOutHeight, maBackground);
- if (eRasterOp != ROP_OVERPAINT)
+ if (eRasterOp != RasterOp::OverPaint)
rRenderContext.SetRasterOp(eRasterOp);
}
diff --git a/vcl/source/window/window.cxx b/vcl/source/window/window.cxx
index 1df5038d7406..ac14dd2c4f09 100644
--- a/vcl/source/window/window.cxx
+++ b/vcl/source/window/window.cxx
@@ -835,7 +835,7 @@ bool Window::AcquireGraphics() const
if ( mpGraphics )
{
- mpGraphics->SetXORMode( (ROP_INVERT == meRasterOp) || (ROP_XOR == meRasterOp) );
+ mpGraphics->SetXORMode( (RasterOp::Invert == meRasterOp) || (RasterOp::Xor == meRasterOp) );
mpGraphics->setAntiAliasB2DDraw(bool(mnAntialiasing & AntialiasingFlags::EnableB2dDraw));
}
@@ -3654,7 +3654,7 @@ Selection Window::GetSurroundingTextSelection() const
bool Window::UsePolyPolygonForComplexGradient()
{
- if ( meRasterOp != ROP_OVERPAINT )
+ if ( meRasterOp != RasterOp::OverPaint )
return true;
return false;
diff --git a/vcl/workben/outdevgrind.cxx b/vcl/workben/outdevgrind.cxx
index 1b983bcd2f3a..ced001f178a2 100644
--- a/vcl/workben/outdevgrind.cxx
+++ b/vcl/workben/outdevgrind.cxx
@@ -625,37 +625,37 @@ void outDevGrind(vcl::RenderContext& rTarget)
{
rTarget.SetLineColor( Color(COL_BLACK) );
rTarget.SetFillColor( Color(COL_GREEN) );
- rTarget.SetRasterOp( ROP_OVERPAINT );
+ rTarget.SetRasterOp( RasterOp::OverPaint );
rTarget.SetClipRegion();
grindFunc( rTarget, iter, nTurns, "w/o clip, w/o xor" );
rTarget.SetLineColor( Color(COL_BLACK) );
rTarget.SetFillColor( Color(COL_GREEN) );
- rTarget.SetRasterOp( ROP_OVERPAINT );
+ rTarget.SetRasterOp( RasterOp::OverPaint );
rTarget.SetClipRegion( vcl::Region( aClipRect ) );
grindFunc( rTarget, iter, nTurns, "with rect clip, w/o xor" );
rTarget.SetLineColor( Color(COL_BLACK) );
rTarget.SetFillColor( Color(COL_GREEN) );
- rTarget.SetRasterOp( ROP_OVERPAINT );
+ rTarget.SetRasterOp( RasterOp::OverPaint );
rTarget.SetClipRegion( vcl::Region( aClipPoly ) );
grindFunc( rTarget, iter, nTurns, "with complex clip, w/o xor" );
rTarget.SetLineColor( Color(COL_BLACK) );
rTarget.SetFillColor( Color(COL_GREEN) );
- rTarget.SetRasterOp( ROP_XOR );
+ rTarget.SetRasterOp( RasterOp::Xor );
rTarget.SetClipRegion();
grindFunc( rTarget, iter, nTurns, "w/o clip, with xor" );
rTarget.SetLineColor( Color(COL_BLACK) );
rTarget.SetFillColor( Color(COL_GREEN) );
- rTarget.SetRasterOp( ROP_XOR );
+ rTarget.SetRasterOp( RasterOp::Xor );
rTarget.SetClipRegion( vcl::Region( aClipRect ) );
grindFunc( rTarget, iter, nTurns, "with rect clip, with xor" );
rTarget.SetLineColor( Color(COL_BLACK) );
rTarget.SetFillColor( Color(COL_GREEN) );
- rTarget.SetRasterOp( ROP_XOR );
+ rTarget.SetRasterOp( RasterOp::Xor );
rTarget.SetClipRegion( vcl::Region( aClipPoly ) );
grindFunc( rTarget, iter, nTurns, "with complex clip, with xor" );
diff --git a/vcl/workben/vcldemo.cxx b/vcl/workben/vcldemo.cxx
index 81df47ab87f3..c301bd75b71f 100644
--- a/vcl/workben/vcldemo.cxx
+++ b/vcl/workben/vcldemo.cxx
@@ -625,9 +625,9 @@ public:
aTextRect.Left()+1, aTextRect.Top()+1,
aTextRect.Right()-1, aTextRect.Bottom()-1);
rDev.SetLineColor(COL_WHITE);
- rDev.SetRasterOp(ROP_XOR);
+ rDev.SetRasterOp(RasterOp::Xor);
rDev.DrawRect(aInnerRect);
- rDev.SetRasterOp(ROP_OVERPAINT);
+ rDev.SetRasterOp(RasterOp::OverPaint);
}
// DX array rendering
@@ -640,9 +640,9 @@ public:
aTop.Move(pItems[j], 0);
aBottom.Move(pItems[j], aTextRect.GetHeight());
rDev.SetLineColor(COL_RED);
- rDev.SetRasterOp(ROP_XOR);
+ rDev.SetRasterOp(RasterOp::Xor);
rDev.DrawLine(aTop,aBottom);
- rDev.SetRasterOp(ROP_OVERPAINT);
+ rDev.SetRasterOp(RasterOp::OverPaint);
}
delete[] pItems;
@@ -1154,7 +1154,7 @@ public:
AntialiasingFlags nFlags = rDev.GetAntialiasing();
rDev.SetAntialiasing(nFlags & ~AntialiasingFlags::EnableB2dDraw);
- rDev.SetRasterOp( ROP_XOR );
+ rDev.SetRasterOp( RasterOp::Xor );
rCtx.mpDemoRenderer->drawThumbs(rDev, r, true);
diff --git a/vcl/source/gdi/svmconverter.cxx b/vcl/source/gdi/svmconverter.cxx
index f9b4486c0b48..7086c21d8d30 100644
--- a/vcl/source/gdi/svmconverter.cxx
+++ b/vcl/source/gdi/svmconverter.cxx
@@ -744,7 +744,7 @@ void SVMConverter::ImplConvertFromSVM1( SvStream& rIStm, GDIMetaFile& rMtf )
{
ImplReadRect( rIStm, aRect );
rMtf.AddAction( new MetaPushAction( PushFlags::RASTEROP ) );
- rMtf.AddAction( new MetaRasterOpAction( ROP_INVERT ) );
+ rMtf.AddAction( new MetaRasterOpAction( RasterOp::Invert ) );
rMtf.AddAction( new MetaRectAction( aRect ) );
rMtf.AddAction( new MetaPopAction() );
}
@@ -1110,16 +1110,16 @@ void SVMConverter::ImplConvertFromSVM1( SvStream& rIStm, GDIMetaFile& rMtf )
switch( nRasterOp )
{
case 1:
- eRasterOp = ROP_INVERT;
+ eRasterOp = RasterOp::Invert;
break;
case 4:
case 5:
- eRasterOp = ROP_XOR;
+ eRasterOp = RasterOp::Xor;
break;
default:
- eRasterOp = ROP_OVERPAINT;
+ eRasterOp = RasterOp::OverPaint;
break;
}
@@ -2117,11 +2117,11 @@ sal_uLong SVMConverter::ImplWriteActions( SvStream& rOStm, GDIMetaFile& rMtf,
{
const MetaRasterOpAction* pAct = static_cast<const MetaRasterOpAction*>(pAction);
- if( ( pAct->GetRasterOp() != ROP_0 ) && ( pAct->GetRasterOp() != ROP_1 ) )
+ if( ( pAct->GetRasterOp() != RasterOp::N0 ) && ( pAct->GetRasterOp() != RasterOp::N1 ) )
{
sal_Int16 nRasterOp;
// If ROP_0/1 was set earlier, restore old state
// via a Pop first
if( rRop_0_1 )
{
@@ -2133,10 +2133,10 @@ sal_uLong SVMConverter::ImplWriteActions( SvStream& rOStm, GDIMetaFile& rMtf,
switch( pAct->GetRasterOp() )
{
- case ROP_OVERPAINT : nRasterOp = 0; break;
- case ROP_XOR : nRasterOp = 4; break;
- case ROP_INVERT: nRasterOp = 1; break;
- default: nRasterOp = 0; break;
+ case RasterOp::OverPaint : nRasterOp = 0; break;
+ case RasterOp::Xor : nRasterOp = 4; break;
+ case RasterOp::Invert: nRasterOp = 1; break;
+ default: nRasterOp = 0; break;
}
ImplWriteRasterOpAction( rOStm, nRasterOp );
@@ -2147,7 +2147,7 @@ sal_uLong SVMConverter::ImplWriteActions( SvStream& rOStm, GDIMetaFile& rMtf,
ImplWritePushAction( rOStm );
rSaveVDev.Push();
- if( pAct->GetRasterOp() == ROP_0 )
+ if( pAct->GetRasterOp() == RasterOp::N0 )
{
ImplWriteLineColor( rOStm, COL_BLACK, 1 );
ImplWriteFillColor( rOStm, COL_BLACK, 1 );
@@ -2117,11 +2117,11 @@ sal_uLong SVMConverter::ImplWriteActions( SvStream& rOStm, GDIMetaFile& rMtf,
{
sal_Int16 nRasterOp;
- // If ROP_0/1 was set earlier, restore old state
+ // If RasterOp::N0/1 was set earlier, restore old state
// via a Pop first
if( rRop_0_1 )